Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(668)

Unified Diff: net/nqe/network_quality_estimator_params.h

Issue 2763853002: Use Android callback API to obtain cellular signal strength (Closed)
Patch Set: comments Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/nqe/network_quality_estimator.cc ('k') | net/nqe/network_quality_estimator_params.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/nqe/network_quality_estimator_params.h
diff --git a/net/nqe/network_quality_estimator_params.h b/net/nqe/network_quality_estimator_params.h
index da8d17bf79d03d16eb2c5e3a2de4c50094e8875f..f6ed118701b83c84e5934295e4485769875561a4 100644
--- a/net/nqe/network_quality_estimator_params.h
+++ b/net/nqe/network_quality_estimator_params.h
@@ -79,10 +79,10 @@ class NET_EXPORT NetworkQualityEstimatorParams {
}
// Returns the factor by which the weight of an observation reduces for every
- // dBm difference between the current signal strength (in dBm), and the signal
- // strength at the time when the observation was taken.
- double weight_multiplier_per_dbm() const {
- return weight_multiplier_per_dbm_;
+ // signal strength level difference between the current signal strength, and
+ // the signal strength at the time when the observation was taken.
+ double weight_multiplier_per_signal_strength_level() const {
+ return weight_multiplier_per_signal_strength_level_;
}
// Returns the fraction of URL requests that should record the correlation
@@ -124,7 +124,7 @@ class NET_EXPORT NetworkQualityEstimatorParams {
const size_t throughput_min_requests_in_flight_;
const double weight_multiplier_per_second_;
- const double weight_multiplier_per_dbm_;
+ const double weight_multiplier_per_signal_strength_level_;
const double correlation_uma_logging_probability_;
const base::Optional<EffectiveConnectionType>
forced_effective_connection_type_;
« no previous file with comments | « net/nqe/network_quality_estimator.cc ('k') | net/nqe/network_quality_estimator_params.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698